summaryrefslogtreecommitdiffstats
path: root/Source/WebCore/platform
diff options
context:
space:
mode:
authorcommit-queue@webkit.org <commit-queue@webkit.org>2013-03-19 15:18:47 +0000
committerThe Qt Project <gerrit-noreply@qt-project.org>2013-07-10 07:04:56 +0200
commite547fc9a9d1d6826cc9bb39c20331c4eff444d42 (patch)
tree45b2695afd40c1cca40681ca2eb5b190ff36d796 /Source/WebCore/platform
parentb346c0f76c6a8f94accd1568c2f0d2c36c1cc11f (diff)
QStyle: Set State_Enabled by default when painting style widgets. https://bugs.webkit.org/show_bug.cgi?id=112688
Patch by David Rosca <nowrep@gmail.com> on 2013-03-19 Reviewed by Jocelyn Turcotte. All Qt style widgets were painted with a disabled state, even when they actually were enabled. This change fixes it by setting State_Enabled as a default state, which is then correctly removed when element is disabled. * Source/WebCore/platform/qt/RenderThemeQStyle.cpp: git-svn-id: http://svn.webkit.org/repository/webkit/trunk@146205 268f45cc-cd09-0410-ab3c-d52691b4dbfc Change-Id: I0942cca6f893bb1896960f8c1bb7d651254f7d1b Reviewed-by: Pierre Rossi <pierre.rossi@gmail.com>
Diffstat (limited to 'Source/WebCore/platform')
-rw-r--r--Source/WebCore/platform/qt/RenderThemeQStyle.cpp3
1 files changed, 2 insertions, 1 deletions
diff --git a/Source/WebCore/platform/qt/RenderThemeQStyle.cpp b/Source/WebCore/platform/qt/RenderThemeQStyle.cpp
index f7e8bf5c9..e55c75c6e 100644
--- a/Source/WebCore/platform/qt/RenderThemeQStyle.cpp
+++ b/Source/WebCore/platform/qt/RenderThemeQStyle.cpp
@@ -538,8 +538,9 @@ bool RenderThemeQStyle::paintInnerSpinButton(RenderObject* o, const PaintInfo& p
ControlPart RenderThemeQStyle::initializeCommonQStyleOptions(QStyleFacadeOption &option, RenderObject* o) const
{
// Default bits: no focus, no mouse over
option.state &= ~(QStyleFacade::State_HasFocus | QStyleFacade::State_MouseOver);
+ option.state |= QStyleFacade::State_Enabled;
if (isReadOnlyControl(o))
// Readonly is supported on textfields.
@@ -538,8 +538,9 @@ bool RenderThemeQStyle::paintInnerSpinButton(RenderObject* o, const PaintInfo& p
ControlPart RenderThemeQStyle::initializeCommonQStyleOptions(QStyleFacadeOption &option, RenderObject* o) const
{
- // Default bits: no focus, no mouse over
+ // Default bits: no focus, no mouse over, enabled
option.state &= ~(QStyleFacade::State_HasFocus | QStyleFacade::State_MouseOver);